#!/usr/local/bin/perl
# =============================================================================
# MODULE: coal.pl -- Basic COAL format alignment utilities
#
# PROGRAMMER: Michel Simard -- TAO
#
# COMMENTS: 
#
#    Copyright (C) 1996, Government of Canada,
#          Center for Information Technology Innovation (CITI),
#          All rights reserved.
#
# =============================================================================


# -----------------------------------------------------------------------------
# COAL stuff
# -----------------------------------------------------------------------------
sub ReadAlignment {
    my ($file) = @_;
    my @couple = ();
    my @al = ([0,0]);

    open(FILE, "<$file") || die "Can't open $file.";
    while (@couple = NextCouple(FILE, @couple)) {
	push @al, [$couple[3], $couple[4]];
    }

    return @al;
}

sub NextCouple {
    my ($in, @couple) = @_;
    
    my ($n, $x0, $y0, $x1, $y1, $comment);
    my ($line, $x2, $y2);

    while ($line = <$in>) {
	chomp $line;
	if ($line =~ /^\s*([.0-9]+)\s+([.0-9]+)\s*(.*)$/o) {
	    ($x2, $y2, $comment) = ($1, $2, $3);
	    if (@couple) {
		($n, $x0, $y0, $x1, $y1) = @couple;
		return ($n+1, $x1, $y1, $x2, $y2, $comment);
	    } elsif (($x2 == 0) && ($y2 == 0)) {
		@couple = (1, -1, -1, 0, 0);
	    } else {
		return (1, 0, 0, $x2, $y2, $comment);
	    }		
	}
    }
    return ();
}


sub NextPoint {
    local ($stream) = @_;
    
    my ($line, $match);

    while ($line = <$stream>) {
	chop $line;
	if ($line =~ /^\s*([.0-9]+)\s+([.0-9]+)/o) {
	    return ($1, $2);
	}
    }

    return ();
}


1;
